==> elgg-2.3.8.zip: elgg-2.3.8/mod/reportedcontent/languages/nl.php <==
<?php
return array(

	'item:object:reported_content' => 'Gemelde items',
	'admin:administer_utilities:reportedcontent' => 'Gemelde inhoud',
	'reportedcontent' => 'Gemelde inhoud',
	'reportedcontent:this' => 'Meld dit',
	'reportedcontent:this:tooltip' => 'Meld dit aan de beheerder',
	'reportedcontent:none' => 'Er is geen gemelde inhoud',
	'reportedcontent:report' => 'Meld aan beheerder',
	'reportedcontent:deleted' => 'De gemelde inhoud is verwijderd',
	'reportedcontent:notdeleted' => 'We konden de gemelde inhoud niet verwijderen',
	'reportedcontent:delete' => 'Verwijder de melding',
	'reportedcontent:areyousure' => 'Weet je zeker dat je dit wilt verwijderen?',
	'reportedcontent:archive' => 'Archiveer de melding',
	'reportedcontent:archived' => 'De melding is gearchiveerd',
	'reportedcontent:visit' => 'Bekijk gemelde inhoud',
	'reportedcontent:by' => 'Gemeld door',
	'reportedcontent:objecttitle' => 'Paginatitel',
	'reportedcontent:objecturl' => 'Pagina-URL',
	'reportedcontent:reason' => 'Reden van melding',
	'reportedcontent:description' => 'Om welke reden wil je dit melden?',
	'reportedcontent:address' => 'Locatie van het item',
	'reportedcontent:success' => 'Je melding is verstuurd naar de sitebeheerder',
	'reportedcontent:failing' => 'Je melding kon niet worden verzonden',
	'reportedcontent:refresh' => 'Ververs deze lijst',
	'reportedcontent:report' => 'Meld aan beheerder',
	'reportedcontent:instructions' => 'De melding zal worden verstuurd aan de beheerders van deze site ter controle.',
	'reportedcontent:numbertodisplay' => 'Aantal meldingen om weer te geven',
	'reportedcontent:widget:description' => 'Toon gemelde inhoud',
	'reportedcontent:user' => 'Meld deze gebruiker bij de sitebeheerder',

	'reportedcontent:failed' => 'Sorry, de poging om deze inhoud te melden is mislukt.',
	'reportedcontent:notarchived' => 'Het was niet mogelijk om deze melding te archiveren',
);

==> elgg-3.0.5.zip: elgg-3.0.5/mod/reportedcontent/languages/nl.php <==
<?php
return array(

	'item:object:reported_content' => 'Gemelde items',
	'admin:administer_utilities:reportedcontent' => 'Gemelde inhoud',
	'reportedcontent' => 'Gemelde inhoud',
	'reportedcontent:this' => 'Meld dit',
	'reportedcontent:this:tooltip' => 'Meld dit aan de beheerder',
	'reportedcontent:none' => 'Er is geen gemelde inhoud',
	'reportedcontent:report' => 'Meld aan beheerder',
	'reportedcontent:deleted' => 'De gemelde inhoud is verwijderd',
	'reportedcontent:notdeleted' => 'We konden de gemelde inhoud niet verwijderen',
	'reportedcontent:delete' => 'Verwijder de melding',
	'reportedcontent:archive' => 'Archiveer de melding',
	'reportedcontent:archived' => 'De melding is gearchiveerd',
	'reportedcontent:by' => 'Gemeld door',
	'reportedcontent:objecttitle' => 'Paginatitel',
	'reportedcontent:objecturl' => 'Pagina-URL',
	'reportedcontent:reason' => 'Reden van melding',
	'reportedcontent:description' => 'Om welke reden wil je dit melden?',
	'reportedcontent:address' => 'Locatie van het item',
	'reportedcontent:success' => 'Je melding is verstuurd naar de sitebeheerder',
	'reportedcontent:refresh' => 'Ververs deze lijst',
	'reportedcontent:report' => 'Meld aan beheerder',
	'reportedcontent:instructions' => 'De melding zal worden verstuurd aan de beheerders van deze site ter controle.',
	'reportedcontent:numbertodisplay' => 'Aantal meldingen om weer te geven',
	'reportedcontent:user' => 'Meld deze gebruiker bij de sitebeheerder',

	'reportedcontent:failed' => 'Sorry, de poging om deze inhoud te melden is mislukt.',
	'reportedcontent:notarchived' => 'Het was niet mogelijk om deze melding te archiveren',
	
	'widgets:reportedcontent:name' => 'Gemelde inhoud',
	'widgets:reportedcontent:description' => 'Toon gemelde inhoud',
);
